@@ -50,6 +50,8 @@ class RackspaceMonitoringValidationError(LibcloudError):
         self.details = details
         super(RackspaceMonitoringValidationError, self).__init__(value=message,
                                                                  driver=driver)
+    def __str__(self):
+        return self.__repr__()
 
     def __repr__(self):
         string = '<ValidationError type=%s, ' % (self.type)
@@ -65,6 +67,9 @@ class LatestAlarmState(object):
         self.timestamp = timestamp
         self.state = state
 
+    def __str__(self):
+        return self.__repr__()
+
     def __repr__(self):
         return ('<LatestAlarmState: entity_id=%s, check_id=%s, alarm_id=%s, '
                 'state=%s ...>' %
@@ -464,7 +469,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
                             kwargs=kwargs)
 
     def update_notification(self, notification, data, **kwargs):
-        return self._update("/notifications/%s" % (notification.id),
+        return self._update('/notifications/%s' % (notification.id),
             data=data, kwargs=kwargs, coerce=self.get_notification)
 
     def create_notification(self, **kwargs):
@@ -477,6 +482,20 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return self._create("/notifications", data=data,
                             coerce=self.get_notification)
 
+    def test_existing_notification(self, notification):
+        resp = self.connection.request('/notifications/%s/test' % (notification.id),
+                                       method='POST')
+        return resp.object
+
+    def test_notification(self, **kwargs):
+        data = {'who': kwargs.get('who'),
+                'why': kwargs.get('why'),
+                'type': kwargs.get('type'),
+                'details': kwargs.get('details')}
+        resp = self.connection.request('/test-notification', method='POST', data=data)
+        return resp.object
+
+
     ####################
     ## Notification Plan
     ####################
